===
XY
===

XY commands are used to plot X-Y data and store its display attributes and to write X-Y data to an ASCII file.


Create XY Objects in Session
-----------------------------

.. autoclass:: abaqus.XY.XYSession.XYSession
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::


Classes
-------

XY features for Session
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.XY.XYSessionBase.XYSessionBase
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

Area
~~~~

.. autoclass:: abaqus.XY.Area.Area
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

AreaStyle
~~~~~~~~~

.. autoclass:: abaqus.XY.AreaStyle.AreaStyle
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

Axis
~~~~

.. autoclass:: abaqus.XY.Axis.Axis
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

AxisArray
~~~~~~~~~

.. autoclass:: abaqus.XY.AxisArray.AxisArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

AxisData
~~~~~~~~

.. autoclass:: abaqus.XY.AxisData.AxisData
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

Chart
~~~~~

.. autoclass:: abaqus.XY.Chart.Chart
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

DefaultChartOptions
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.XY.DefaultChartOptions.DefaultChartOptions
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

DefaultPlot
~~~~~~~~~~~

.. autoclass:: abaqus.XY.DefaultPlot.DefaultPlot
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

Legend
~~~~~~

.. autoclass:: abaqus.XY.Legend.Legend
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

LineStyle
~~~~~~~~~

.. autoclass:: abaqus.XY.LineStyle.LineStyle
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

QuantityType
~~~~~~~~~~~~

.. autoclass:: abaqus.XY.QuantityType.QuantityType
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

SymbolStyle
~~~~~~~~~~~

.. autoclass:: abaqus.XY.SymbolStyle.SymbolStyle
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

TextStyle
~~~~~~~~~

.. autoclass:: abaqus.XY.TextStyle.TextStyle
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

Title
~~~~~

.. autoclass:: abaqus.XY.Title.Title
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

writeXYReport
~~~~~~~~~~~~~

.. automodule:: abaqus.XY.writeXYReport
    :members:
    :special-members: __init__
    :show-inheritance:

XYCurve
~~~~~~~

.. autoclass:: abaqus.XY.XYCurve.XYCurve
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

XYCurveArray
~~~~~~~~~~~~

.. autoclass:: abaqus.XY.XYCurveArray.XYCurveArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

XYData
~~~~~~

.. autoclass:: abaqus.XY.XYData.XYData
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

XYPlot
~~~~~~

.. autoclass:: abaqus.XY.XYPlot.XYPlot
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

.. autoclass:: abaqus.XY.XYPlotBase.XYPlotBase
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

XYReportOptions
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.XY.XYReportOptions.XYReportOptions
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

